==> 1.0.0.1.zip: pixieditor/README.md <==
<img src="https://user-images.githubusercontent.com/25402427/102633463-c1d3bb80-4150-11eb-8262-535e568fa781.png" width="700">

---

**PixiEditor** is a Pixel art editing software. Create beautiful sprites for your games, animations (coming soon!), and edit images. All packed in eye-friendly dark theme.

[![Build Status](https://img.shields.io/azure-devops/build/flabbet/PixiEditor/6/master)](https://dev.azure.com/flabbet/PixiEditor/_build?definitionId=6) 
[![CodeFactor](https://www.codefactor.io/repository/github/pixieditor/pixieditor/badge)](https://www.codefactor.io/repository/github/pixieditor/pixieditor)
[![Release](https://img.shields.io/github/v/release/flabbet/PixiEditor)](https://github.com/flabbet/PixiEditor/releases) 
[![Downloads](https://img.shields.io/github/downloads/PixiEditor/PixiEditor/total)](https://github.com/flabbet/PixiEditor/releases)
[![Discord Server](https://badgen.net/badge/discord/join%20chat/7289DA?icon=discord)](https://discord.gg/qSRMYmq)
[![Subreddit subscribers](https://img.shields.io/reddit/subreddit-subscribers/PixiEditor?label=%20r%2FPixiEditor&logoColor=%23e3002d)](https://reddit.com/r/PixiEditor)
[![contributions](https://img.shields.io/badge/contributions-open-brightgreen)](https://github.com/flabbet/PixiEditor/pulls)

### Check out our website [pixieditor.net](https://pixieditor.net)

## About PixiEditor

Want to create beautiful pixel art for your games? PixiEditor can help you! Our goal is to create a fully open-source, fast, and feature-rich pixel art creator. 

### Familiar interface

Have you ever used Photoshop or Gimp? Reinventing the wheel is unnecessary, we wanted users to get familiar with the tool quickly and with ease. 

![](https://user-images.githubusercontent.com/45312141/146670495-ae521a18-a89e-4e94-9317-6838b51407fa.png)


### Fast

PixiEditor is fast, drawing feels smooth on any canvas size, we've developed original chunk-based system and adaptive rendering to minimize pixel processing time.

### Active development

PixiEditor started in 2018 and it's been actively developed since. We continuously improve code quality to ensure the best experience and performance.


## Installation

<a href='//www.microsoft.com/store/apps/9NDDRHS8PBRN?cid=storebadge&ocid=badge'><img src='https://developer.microsoft.com/store/badges/images/English_get-it-from-MS.png' alt='Microsoft Store badge' width="184"/></a>

Wishlist on Steam now!

[![wishlist_steam](https://user-images.githubusercontent.com/25402427/214952291-d81a4d79-bb75-44f2-bd24-10d7c3404997.png)](https://store.steampowered.com/app/2218560/PixiEditor__Pixel_Art_Editor?utm_source=GitHub)

**Or**

Follow these instructions to get PixiEditor working on your machine.

1. Download the zipped installer from our [official website](https://pixieditor.net/download)
2. Extract the installer from the archive
3. Launch it
4. Follow the steps in the installer to finish the installation


## Featured content

### PixiEditor 1.0 Trailer

[![Trailer](https://img.youtube.com/vi/UK8HnrAQhCo/0.jpg)](https://www.youtube.com/watch?v=UK8HnrAQhCo)

### Pixel Art Timelapse - "Bog Landscape" | PixiEditor

[![Landscape timelapse](https://img.youtube.com/vi/bzC-wy6HCB8/0.jpg)](https://www.youtube.com/watch?v=bzC-wy6HCB8)

### Gallery

Check out some pixel arts made with PixiEditor [here](https://github.com/PixiEditor/PixiEditor/wiki/Gallery).


## Support

Struggling with something? You can find support in a few places:

* Check out [documentation](https://github.com/flabbet/PixiEditor/wiki)

* Ask on [Discord](https://discord.gg/qSRMYmq)
* Open new [Issue](https://github.com/flabbet/PixiEditor/issues)
* Check out the [FAQ](https://github.com/PixiEditor/PixiEditor/wiki/FAQ). 



## Building from source

### Software Requirements

* .NET 7

* latest Visual Studio 2022 (in order to code generators to work)

### Instructions

1. Clone Repository

2. Open PixiEditor/src/PixiEditor/PixiEditor.sln in Visual Studio

3. Build solution

## Contributing 

Please read [CONTRIBUTING.md](https://github.com/flabbet/PixiEditor/blob/master/CONTRIBUTING.md) for details on our code of conduct, and the process for submitting pull requests to us.

## License

This project is licensed under the MIT License - see the [LICENSE.md](https://github.com/flabbet/PixiEditor/blob/master/LICENSE) - file for details

==> 1.0.1.0.zip: pixieditor/README.md <==
<img src="https://user-images.githubusercontent.com/25402427/102633463-c1d3bb80-4150-11eb-8262-535e568fa781.png" width="700">

---

**PixiEditor** is a Pixel art editing software. Create beautiful sprites for your games, animations (coming soon!), and edit images. All packed in eye-friendly dark theme.

[![Build Status](https://img.shields.io/azure-devops/build/flabbet/PixiEditor/6/master)](https://dev.azure.com/flabbet/PixiEditor/_build?definitionId=6) 
[![CodeFactor](https://www.codefactor.io/repository/github/pixieditor/pixieditor/badge)](https://www.codefactor.io/repository/github/pixieditor/pixieditor)
[![Release](https://img.shields.io/github/v/release/flabbet/PixiEditor)](https://github.com/flabbet/PixiEditor/releases) 
[![Downloads](https://img.shields.io/github/downloads/PixiEditor/PixiEditor/total)](https://github.com/flabbet/PixiEditor/releases)
[![Discord Server](https://badgen.net/badge/discord/join%20chat/7289DA?icon=discord)](https://discord.gg/qSRMYmq)
[![Subreddit subscribers](https://img.shields.io/reddit/subreddit-subscribers/PixiEditor?label=%20r%2FPixiEditor&logoColor=%23e3002d)](https://reddit.com/r/PixiEditor)
[![contributions](https://img.shields.io/badge/contributions-open-brightgreen)](https://github.com/flabbet/PixiEditor/pulls)

### Check out our website [pixieditor.net](https://pixieditor.net)

## About PixiEditor

Want to create beautiful pixel art for your games? PixiEditor can help you! Our goal is to create a fully open-source, fast, and feature-rich pixel art creator. 

### Familiar interface

Have you ever used Photoshop or Gimp? Reinventing the wheel is unnecessary, we wanted users to get familiar with the tool quickly and with ease. 

![](https://user-images.githubusercontent.com/45312141/146670495-ae521a18-a89e-4e94-9317-6838b51407fa.png)


### Fast

PixiEditor is fast, drawing feels smooth on any canvas size, we've developed original chunk-based system and adaptive rendering to minimize pixel processing time.

### Active development

PixiEditor started in 2018 and it's been actively developed since. We continuously improve code quality to ensure the best experience and performance.


## Installation

<a href='//www.microsoft.com/store/apps/9NDDRHS8PBRN?cid=storebadge&ocid=badge'><img src='https://developer.microsoft.com/store/badges/images/English_get-it-from-MS.png' alt='Microsoft Store badge' width="184"/></a>

Get it on Steam now!

[![Get PixiEditor on Steam](https://user-images.githubusercontent.com/121322/228988640-32fe5bd3-9dd0-4f3b-a8f2-f744bd9b50b5.png)](https://store.steampowered.com/app/2218560/PixiEditor__Pixel_Art_Editor?utm_source=GitHub)

**Or**

Follow these instructions to get PixiEditor working on your machine.

1. Download the zipped installer from our [official website](https://pixieditor.net/download)
2. Extract the installer from the archive
3. Launch it
4. Follow the steps in the installer to finish the installation


## Featured content

### PixiEditor 1.0 Trailer

[![Trailer](https://img.youtube.com/vi/UK8HnrAQhCo/0.jpg)](https://www.youtube.com/watch?v=UK8HnrAQhCo)

### Pixel Art Timelapse - "Bog Landscape" | PixiEditor

[![Landscape timelapse](https://img.youtube.com/vi/bzC-wy6HCB8/0.jpg)](https://www.youtube.com/watch?v=bzC-wy6HCB8)

### Gallery

Check out some pixel arts made with PixiEditor [here](https://github.com/PixiEditor/PixiEditor/wiki/Gallery).


## Support

Struggling with something? You can find support in a few places:

* Check out [documentation](https://github.com/flabbet/PixiEditor/wiki)

* Ask on [Discord](https://discord.gg/qSRMYmq)
* Open new [Issue](https://github.com/flabbet/PixiEditor/issues)
* Check out the [FAQ](https://github.com/PixiEditor/PixiEditor/wiki/FAQ). 



## Building from source

### Software Requirements

* .NET 7.0.104 (7.0.202 is broken! Make sure to use 7.0.104)

### Instructions

1. Clone Repository

2. Open PixiEditor/src/PixiEditor/PixiEditor.sln in Visual Studio

3. Build solution

## Contributing 

Please read [CONTRIBUTING.md](https://github.com/flabbet/PixiEditor/blob/master/CONTRIBUTING.md) for details on our code of conduct, and the process for submitting pull requests to us.

## License

This project is licensed under the MIT License - see the [LICENSE.md](https://github.com/flabbet/PixiEditor/blob/master/LICENSE) - file for details
